@@ -123,7 +123,7 @@ class RinnaiWaterHeater(object):
 
         payload = ("{\"AuthFlow\":\"USER_SRP_AUTH\",\"ClientId\":\"%s\",\"AuthParameters\":"
         "{\"USERNAME\":\"%s\",\"SRP_A\":\"%s\"},\"ClientMetadata\":{}}" 
-        % (client_id,username,format(large_a_value,'x')))
+        % (self.client_id,self.username,format(self.large_a_value,'x')))
 
         r = requests.post(
             baseAuthUrl,
